@@ -9,6 +9,7 @@ from pkg_resources import resource_filename # @UnresolvedImport
 
 import gtk
 import logging
+from pyxrd.generic.plot.axes_setup import PositionSetup, update_axes
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
@@ -28,8 +29,6 @@ from pyxrd.data import settings
 from pyxrd.generic.plot.plotters import plot_specimens, plot_mixtures
 from pyxrd.generic.controllers import DialogMixin
 
-from .eye_dropper import EyeDropper
-
 class PlotController(DialogMixin):
     """
         A base class for matplotlib-canvas controllers that, sets up the 
@@ -179,31 +178,25 @@ class MainPlotController (PlotController):
         A controller for the main plot canvas.
     """
     # ------------------------------------------------------------
-    #      Initialisation and other internals
+    #      Initialization and other internals
     # ------------------------------------------------------------
     def __init__(self, app_controller, *args, **kwargs):
         self.labels = list()
         self.marker_lbls = list()
         self.scale = 1.0
         self.stats = False
-        self.xdiff = 30.0
-        self.plot_left = settings.PLOT_LEFT
-        self.plot_bottom = settings.PLOT_BOTTOM
-        self.plot_top = settings.PLOT_TOP
+
+        self.position_setup = PositionSetup()
 
         self.app_controller = app_controller
         PlotController.__init__(self, *args, **kwargs)
 
     def setup_content(self):
-        self.title = self.figure.text(s="", va='bottom', ha='left', x=0.1, y=0.1, weight="bold")
+        # Create subplot and add it to the figure:
         self.plot = Subplot(self.figure, 211, axisbg=(1.0, 1.0, 1.0, 0.0))
         self.figure.add_axes(self.plot)
-        self.plot.axis["right"].set_visible(False)
-        self.plot.axis["left"].set_visible(False)
-        self.plot.axis["top"].set_visible(False)
-        self.plot.get_xaxis().tick_bottom()
-        self.plot.get_yaxis().tick_left()
 
+        # Connect events:
         self.canvas.mpl_connect('draw_event', self.fix_after_drawing)
         self.canvas.mpl_connect('resize_event', self.fix_after_drawing)
 
@@ -219,7 +212,10 @@ class MainPlotController (PlotController):
         if clear: self.plot.cla()
 
         if project and specimens:
-            self.labels, self.marker_lbls = plot_specimens(project, specimens, self.plot_left, self.plot)
+            self.labels, self.marker_lbls = plot_specimens(
+                self.plot, self.position_setup,
+                project, specimens
+            )
             # get mixtures for the selected specimens:
             mixtures = []
             for mixture in project.mixtures:
@@ -227,74 +223,15 @@ class MainPlotController (PlotController):
                     if specimen in mixture.specimens:
                         mixtures.append(mixture)
                         break
-            plot_mixtures(project, mixtures, self.plot)
-        self.update_axes(project=project)
+            plot_mixtures(self.plot, project, mixtures)
 
-    def update_axes(self, project=None):
-        """
-            Updates the view limits and displays statistics plot if needed         
-        """
-        self.stretch = project.axes_xstretch if project is not None else False
-
-        self.update_lim(project=project)
-        xaxis = self.plot.get_xaxis()
-        # yaxis = self.plot.get_yaxis()
-        xmin, xmax = xaxis.get_view_interval()
-        # ymin, ymax = yaxis.get_view_interval()
-        self.xdiff = xmax - xmin
-
-        if project == None or project.axes_yvisible == False:
-            self.plot.axis["left"].set_visible(False)
-        else:
-            self.plot.axis["left"].set_visible(True)
-        self.plot.axis["bottom"].major_ticks.set_visible(True)
-        self.plot.axis["right"].set_visible(False)
-        self.plot.axis["top"].set_visible(False)
-
-
-        def set_label_text(label, text):
-            label.set_text(text)
-            label.set_weight('heavy')
-            label.set_size(16)
-
-        self.plot.set_position(self.get_plot_position())
-
-        set_label_text(self.plot.axis["bottom"].label, u'Angle (°2θ)')
-        self.plot.axis["bottom"].major_ticklabels.set_visible(True)
+        update_axes(
+            self.plot, self.position_setup,
+            project, specimens
+        )
 
         self.draw()
 
-    def update_lim(self, project=None):
-        """
-            Updates the view limits
-        """
-        self.plot.relim()
-        self.plot.autoscale_view()
-
-        self.plot.set_ylim(bottom=0, auto=True)
-
-        # Adjust limits if needed:
-        xmin, xmax = 0.0, 20.0
-        if project is None or project.axes_xlimit == 0:
-            xmin, xmax = self.plot.get_xlim()
-            xmin, xmax = max(xmin, 0.0), max(xmax, 20.0)
-        else:
-            xmin, xmax = max(project.axes_xmin, 0.0), project.axes_xmax
-        self.plot.set_xlim(left=xmin, right=xmax, auto=False)
-
-        if project is not None and project.axes_ylimit != 0:
-            scale, _ = project.get_scale_factor()
-
-            ymin = max(project.axes_ymin, 0.0)
-            ymax = project.axes_ymax
-            if ymax <= 0:
-                ymax = self.plot.get_ylim()[1]
-            else:
-                ymax = ymax * scale
-            ymin = ymin * scale
-
-            self.plot.set_ylim(bottom=ymin, top=ymax, auto=False)
-
     # ------------------------------------------------------------
     #      Plot position and size calculations
     # ------------------------------------------------------------
@@ -339,19 +276,19 @@ class MainPlotController (PlotController):
         # Fix left side for wide specimen labels:
         if len(self.labels) > 0:
             bbox = self._get_joint_bbox(self.labels)
-            self.plot_left = 0.05 + bbox.width
+            self.position_setup.left = 0.05 + bbox.width
         # Fix top for high marker labels:
         if len(self.marker_lbls) > 0:
             bbox = self._get_joint_bbox([ label for label, flag, _ in self.marker_lbls if flag ])
-            if bbox is not None: self.plot_top = 1.0 - (0.05 + bbox.height) #Figure top - marker margin
+            if bbox is not None: self.position_setup.top = 1.0 - (0.05 + bbox.height) #Figure top - marker margin
         # Fix bottom for x-axis label:
         bottom_label = self.plot.axis["bottom"].label
         if bottom_label is not None:
             bbox = self._get_joint_bbox([bottom_label])
-            if bbox is not None: self.plot_bottom = 0.10 - min(bbox.ymin, 0.0)
+            if bbox is not None: self.position_setup.bottom = 0.10 - min(bbox.ymin, 0.0)
 
         # Calculate new plot position & set it:
-        plot_pos = self.get_plot_position()
+        plot_pos = self.position_setup.position
         self.plot.set_position(plot_pos)
 
         # Adjust specimen label position
@@ -367,40 +304,4 @@ class MainPlotController (PlotController):
 
         return False
 
-    def _get_plot_width(self):
-        MAX_PLOT_WIDTH = settings.MAX_PLOT_RIGHT - self.plot_left
-        if self.stretch:
-            return MAX_PLOT_WIDTH
-        else:
-            return min((self.xdiff / 70), 1.0) * MAX_PLOT_WIDTH
-
-    def _get_plot_height(self):
-        return abs(self.plot_top - self.plot_bottom)
-
-    def get_plot_position(self):
-        """Get the position list of the main plot: [LEFT, BOTTOM, WIDTH, HEIGHT] """
-        return [self.plot_left, self.plot_bottom, self._get_plot_width(), self._get_plot_height()]
-
-    def get_plot_right(self):
-        """Get the rightmost position of the main plot: LEFT + WIDTH """
-        PLOT_WIDTH = self._get_plot_width()
-        return self.plot_left + PLOT_WIDTH
-
-    def get_plot_top(self):
-        """Get the topmost position of the main plot: BOTTOM + HEIGHT """
-        PLOT_HEIGHT = self._get_plot_height()
-        return self.plot_bottom + PLOT_HEIGHT
-
-    def get_user_x_coordinate(self, callback):
-        def onclick(x_pos, event):
-            self.edc.enabled = False
-            self.edc.disconnect()
-            callback(x_pos)
-            del self.edc
-        self.edc = EyeDropper(
-            self.canvas,
-            self.canvas.get_window(),
-            onclick
-        )
-
     pass # end of class
