@@ -11,8 +11,8 @@ logger = logging.getLogger(__name__)
 
 import gtk
 
-from pyxrd.mvc.adapters import DummyAdapter
-from pyxrd.mvc.adapters.gtk_support.tree_view_adapters import wrap_xydata_to_treemodel
+from mvc.adapters import DummyAdapter
+from mvc.adapters.gtk_support.tree_view_adapters import wrap_xydata_to_treemodel
 from pyxrd.generic.controllers import BaseController, DialogController, TreeViewMixin
 from pyxrd.generic.views.treeview_tools import setup_treeview, new_text_column
 
@@ -25,7 +25,8 @@ from pyxrd.generic.controllers.line_controllers import (
     SmoothDataController,
     AddNoiseController,
     ShiftDataController,
-    StripPeakController
+    StripPeakController,
+    CalculatePeakAreaController,
 )
 
 from pyxrd.generic.views.line_views import (
@@ -33,7 +34,8 @@ from pyxrd.generic.views.line_views import (
     SmoothDataView,
     AddNoiseView,
     ShiftDataView,
-    StripPeakView
+    StripPeakView,
+    CalculatePeakAreaView
 )
 from pyxrd.data import settings
 
@@ -178,6 +180,14 @@ class SpecimenController(DialogController, TreeViewMixin):
         StripPeakController(model=self.model.experimental_pattern, view=st_view, parent=self)
         st_view.present()
 
+    def peak_area(self):
+        """
+            Opens the 'peak area' dialog.
+        """
+        pa_view = CalculatePeakAreaView(parent=self.view)
+        CalculatePeakAreaController(model=self.model.experimental_pattern, view=pa_view, parent=self)
+        pa_view.present()
+
     # ------------------------------------------------------------
     #      GTK Signal handlers
     # ------------------------------------------------------------
